import React, { useState, useEffect } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faChevronLeft } from '@fortawesome/free-solid-svg-icons';
import Sidebar from '../sidebar/Sidebar';
import axiosInstance from '../../api/axiosConfig';

const CLASSES = {
  container: 'flex flex-row',
  mainContent: 'w-full flex flex-col min-h-screen text-black',
  innerContent: 'min-h-screen text-gray-800 p-6',
  header: 'flex justify-between items-center',
  headerTitle: 'flex items-center',
  backButton: 'text-[#0e355b] text-xl',
  title: 'text-2xl font-semibold text-[#0e355b]',
  skipLink: 'text-blue-900',
  formGrid: 'grid grid-cols-1 md:grid-cols-3 gap-6',
  imageSection: 'space-y-6',
  imageWrapper: 'text-center',
  imageContainer: 'inline-block relative',
  imagePreview: 'bg-gray-300 w-24 h-24 rounded-full mx-auto overflow-hidden',
  noImage: 'w-full h-full flex items-center justify-center text-gray-500',
  hiddenInput: 'hidden',
  uploadButton:
    'absolute bottom-0 left-1/2 transform -translate-x-1/2 bg-gray-700 text-white text-xs px-2 py-1 rounded-full',
  linkTitle: 'text-lg font-semibold',
  formSection: 'md:col-span-2 space-y-4',
  formGroup: 'block text-gray-800 font-medium',
  formInput: 'w-full p-2 border-b border-gray-400 focus:border-gray-700',
  formSelect: 'w-full p-2 border-b border-gray-400 focus:border-gray-700',
  submitButton: 'bg-[#0e355b] text-white py-2 px-4 rounded-md',
};

const AddCustomer = () => {
  const navigate = useNavigate();
  const [customerData, setCustomerData] = useState({
    firstname: '',
    lastname: '',
    age: '',
    gender: '',
    email: '',
    mobile: '',
    image: null,
    address: {
      address_line_1: '',
      address_line_2: '',
      nearby_landmark: '',
      pincode: '',
      city_id: '',
    },
  });

  const [cities, setCities] = useState([]);
  const [imagePreview, setImagePreview] = useState(null);

  useEffect(() => {
    const fetchCities = async () => {
      try {
        const response = await axiosInstance.get('/cities');
        if (Array.isArray(response.data)) {
          setCities(response.data);
        } else {
          console.error('Error: Data is not an array', response.data);
        }
      } catch (error) {
        console.error('Error fetching cities:', error.response || error.message);
      }
    };

    fetchCities();
  }, []);

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setCustomerData((prevData) => ({
      ...prevData,
      [name]: value,
    }));
  };

  const handleAddressChange = (e) => {
    const { name, value } = e.target;
    setCustomerData((prevData) => ({
      ...prevData,
      address: {
        ...prevData.address,
        [name]: value,
      },
    }));
  };

  const handleImageChange = (e) => {
    const file = e.target.files[0];
    if (file) {
      setCustomerData({
        ...customerData,
        image: file,
      });
      setImagePreview(URL.createObjectURL(file));
    }
  };

  const handleAddCustomerSubmit = async (e) => {
    e.preventDefault();
    const formData = new FormData();
    Object.keys(customerData).forEach((key) => {
      if (key === 'address') {
        Object.keys(customerData.address).forEach((addrKey) => {
          formData.append(`address[${addrKey}]`, customerData.address[addrKey]);
        });
      } else {
        formData.append(key, customerData[key]);
      }
    });

    try {
      const response = await axiosInstance.post(
        'http://localhost:5000/customers',
        formData,
        {
          headers: {
            'Content-Type': 'multipart/form-data',
          },
        }
      );
      console.log('Raw response:', response);
      console.log('Customer added successfully:', response.data);
      navigate('/customers');
    } catch (error) {
      console.error('Error adding customer:', error.response || error.message);
    }
  };

  return (
    <div className={CLASSES.container}>
      <Sidebar />
      <div className={CLASSES.mainContent}>
        <div className={CLASSES.innerContent}>
          <div className={CLASSES.header}>
            <div className={CLASSES.headerTitle}>
              <Link to="/customers" className={CLASSES.backButton}>
                <FontAwesomeIcon icon={faChevronLeft} />
              </Link>
              <h1 className={CLASSES.title}>Add Customer</h1>
            </div>
            <Link to="/CategoryList" className={CLASSES.skipLink}>
              Skip for now
            </Link>
          </div>
          <div className={CLASSES.formGrid}>
            <div className={CLASSES.imageSection}>
              <div className={CLASSES.imageWrapper}>
                <div className={CLASSES.imageContainer}>
                  <div className={CLASSES.imagePreview}>
                    {imagePreview ? (
                      <img
                        src={imagePreview}
                        alt="Customer"
                        className="w-full h-full object-cover"
                      />
                    ) : (
                      <div className={CLASSES.noImage}>No Image</div>
                    )}
                  </div>
                  <input
                    type="file"
                    accept="image/*"
                    className={CLASSES.hiddenInput}
                    id="imageUpload"
                    onChange={handleImageChange}
                  />
                  <button
                    type="button"
                    onClick={() =>
                      document.getElementById('imageUpload').click()
                    }
                    className={CLASSES.uploadButton}
                  >
                    Upload
                  </button>
                </div>
              </div>
              <div>
                <Link to="/add-customer">
                  <h2 className={CLASSES.linkTitle}>Customer Information</h2>
                </Link>
                <Link to="/measurements">
                  <h2 className={CLASSES.linkTitle}>Measurements</h2>
                </Link>
              </div>
            </div>
            <div className={CLASSES.formSection}>
              <form onSubmit={handleAddCustomerSubmit}>
                <div>
                  <label className={CLASSES.formGroup}>First Name:</label>
                  <input
                    type="text"
                    name="firstname"
                    value={customerData.firstname}
                    onChange={handleInputChange}
                    className={CLASSES.formInput}
                  />
                </div>
                <div>
                  <label className={CLASSES.formGroup}>Last Name:</label>
                  <input
                    type="text"
                    name="lastname"
                    value={customerData.lastname}
                    onChange={handleInputChange}
                    className={CLASSES.formInput}
                  />
                </div>
                <div>
                  <label className={CLASSES.formGroup}>Age:</label>
                  <input
                    type="number"
                    name="age"
                    value={customerData.age}
                    onChange={handleInputChange}
                    className={CLASSES.formInput}
                  />
                </div>
                <div>
                  <label className={CLASSES.formGroup}>Gender:</label>
                  <select
                    name="gender"
                    value={customerData.gender}
                    onChange={handleInputChange}
                    className={CLASSES.formSelect}
                  >
                    <option value="" disabled>
                      Select Gender
                    </option>
                    <option value="male">Male</option>
                    <option value="female">Female</option>
                    <option value="other">Other</option>
                  </select>
                </div>
                <div>
                  <label className={CLASSES.formGroup}>Email:</label>
                  <input
                    type="email"
                    name="email"
                    value={customerData.email}
                    onChange={handleInputChange}
                    className={CLASSES.formInput}
                  />
                </div>
                <div>
                  <label className={CLASSES.formGroup}>Address Line 1:</label>
                  <input
                    type="text"
                    name="address_line_1"
                    value={customerData.address.address_line_1}
                    onChange={handleAddressChange}
                    className={CLASSES.formInput}
                  />
                </div>
                <div>
                  <label className={CLASSES.formGroup}>Address Line 2:</label>
                  <input
                    type="text"
                    name="address_line_2"
                    value={customerData.address.address_line_2}
                    onChange={handleAddressChange}
                    className={CLASSES.formInput}
                  />
                </div>
                <div>
                  <label className={CLASSES.formGroup}>Nearby Landmark:</label>
                  <input
                    type="text"
                    name="nearby_landmark"
                    value={customerData.address.nearby_landmark}
                    onChange={handleAddressChange}
                    className={CLASSES.formInput}
                  />
                </div>
                <div>
                  <label className={CLASSES.formGroup}>Pincode:</label>
                  <input
                    type="text"
                    name="pincode"
                    value={customerData.address.pincode}
                    onChange={handleAddressChange}
                    className={CLASSES.formInput}
                  />
                </div>
                <div>
                  <label className={CLASSES.formGroup}>City:</label>
                  <select
                    name="city_id"
                    value={customerData.address.city_id}
                    onChange={handleAddressChange}
                    className={CLASSES.formSelect}
                  >
                    <option value="" disabled>
                      Select City
                    </option>
                    {Array.isArray(cities) &&
                      cities.map((city) => (
                        <option key={city.id} value={city.id}>
                          {city.name}
                        </option>
                      ))}
                  </select>
                </div>
                <div>
                  <label className={CLASSES.formGroup}>Mobile:</label>
                  <input
                    type="tel"
                    name="mobile"
                    value={customerData.mobile}
                    onChange={handleInputChange}
                    className={CLASSES.formInput}
                  />
                </div>
                <div className="flex justify-end">
                  <button type="submit" className={CLASSES.submitButton}>
                    Add Customer
                  </button>
                </div>
              </form>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default AddCustomer;
